@@ -17,6 +17,16 @@ ParseFallout <- function(report.data) {
   # so just leave it as is, but rename the counts column to the metric
   data <- report.data$report$data
   data <- rename(data, c("counts"=report.data$report$metrics$id))
-  return(data)
+  
+  #Get segment 
+  seg <- report.data$report$segments
+  
+  #If segment null, make a dummy data frame
+  if(is.null(seg)){
+    seg <- data.frame(list("", ""))
+  }
+  names(seg) <- c("segment.id", "segment.name")
+  
+  return(cbind(data, seg, row.names=NULL))
 
 }
