@@ -60,7 +60,7 @@
 
 QueueRanked <- function(reportsuite.id, date.from, date.to, metrics, elements,
                         top=0,start=0,selected=c(), search=c(),search.type='or',
-                        segment.id='', segment.inline='', classification=character(0),data.current=FALSE, 
+                        segment.id='', segment.inline='', classification=c(),data.current=FALSE, 
                         expedite=FALSE,interval.seconds=5,max.attempts=120) {
 
   # build JSON description
@@ -103,13 +103,15 @@ QueueRanked <- function(reportsuite.id, date.from, date.to, metrics, elements,
         working.element[["search"]] <- list(type = unbox(search.type), 
                                             keywords = search)
       }
-      if(length(classification)!=0){
-        working.element[["classification"]] <- unbox(classification)
-      }
+
     } else {
       working.element <- list(id = unbox(element), top = unbox("50000"))
     }
 
+    if(length(classification)>=i){
+      working.element[["classification"]] <- unbox(classification[i])
+    }
+
     if(length(elements.formatted)>0) {
       elements.formatted <- append(elements.formatted,list(working.element))
     } else {
@@ -118,7 +120,7 @@ QueueRanked <- function(reportsuite.id, date.from, date.to, metrics, elements,
   }
   report.description$reportDescription$elements <- elements.formatted
 
-  report.data <- JsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts)
+  report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts)
 
   return(report.data) 
 
